==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/GuestAgentProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the guest agent settings for the virtual machine.
 * @property clientPublicKey Gets or sets the Public Key provided by the client for enabling guest management.
 */
public data class GuestAgentProfileArgs(
    public val clientPublicKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs.builder()
            .clientPublicKey(clientPublicKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestAgentProfileArgs].
 */
@PulumiTagMarker
public class GuestAgentProfileArgsBuilder internal constructor() {
    private var clientPublicKey: Output<String>? = null

    /**
     * @param value Gets or sets the Public Key provided by the client for enabling guest management.
     */
    @JvmName("inrkpnslhiuibqvn")
    public suspend fun clientPublicKey(`value`: Output<String>) {
        this.clientPublicKey = value
    }

    /**
     * @param value Gets or sets the Public Key provided by the client for enabling guest management.
     */
    @JvmName("gvsfqbbkqfkemhjg")
    public suspend fun clientPublicKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientPublicKey = mapped
    }

    internal fun build(): GuestAgentProfileArgs = GuestAgentProfileArgs(
        clientPublicKey = clientPublicKey,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/GuestAgentProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the guest agent settings for the virtual machine.
 * @property clientPublicKey Gets or sets the Public Key provided by the client for enabling guest management.
 */
public data class GuestAgentProfileArgs(
    public val clientPublicKey: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GuestAgentProfileArgs.builder()
            .clientPublicKey(clientPublicKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestAgentProfileArgs].
 */
@PulumiTagMarker
public class GuestAgentProfileArgsBuilder internal constructor() {
    private var clientPublicKey: Output<String>? = null

    /**
     * @param value Gets or sets the Public Key provided by the client for enabling guest management.
     */
    @JvmName("tpoaaptvnthhxtgd")
    public suspend fun clientPublicKey(`value`: Output<String>) {
        this.clientPublicKey = value
    }

    /**
     * @param value Gets or sets the Public Key provided by the client for enabling guest management.
     */
    @JvmName("twryvqyvkiehdlak")
    public suspend fun clientPublicKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientPublicKey = mapped
    }

    internal fun build(): GuestAgentProfileArgs = GuestAgentProfileArgs(
        clientPublicKey = clientPublicKey,
    )
}
